//
//  View.swift
//  Slider
//
//  Created by Mark Meretzky on 9/15/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class View: UIView {
	let slider: UISlider = UISlider();
	let label: UILabel = UILabel();

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);

		// Initialization code
		backgroundColor = UIColor.whiteColor();

		slider.frame.size.width = 0.8 * bounds.size.width;
		slider.center = center;

		slider.autoresizingMask =
			  UIViewAutoresizing.FlexibleLeftMargin
			| UIViewAutoresizing.FlexibleRightMargin
			| UIViewAutoresizing.FlexibleTopMargin
			| UIViewAutoresizing.FlexibleBottomMargin
			| UIViewAutoresizing.FlexibleWidth;

		slider.minimumValue = 32;	//freezing & boiling points of water in Fahrenheit
		slider.maximumValue = 212;
		slider.value = (slider.minimumValue + slider.maximumValue) / 2;
		slider.continuous = true;	//the default

		slider.addTarget(self,
			action: "valueChanged:",
			forControlEvents: UIControlEvents.ValueChanged);

		//Monospace font to keep the text stable as the numbers change.
		label.font = UIFont(name: "Courier", size: 26);
		label.textAlignment = NSTextAlignment.Center;
		label.textColor = UIColor.whiteColor();

		addSubview(slider);
		addSubview(label);
		valueChanged(slider);	//write initial temperatures into the label
	}

	//Center the label below the slider, separated by a margin.
	
	override func layoutSubviews() {
		let m: CGFloat = min(bounds.size.width, bounds.size.height);
		let margin: CGFloat = m / 30;

		label.frame = CGRectMake(
			slider.frame.origin.x,
			slider.frame.origin.y + slider.frame.size.height + margin,
			slider.frame.size.width,
			slider.frame.size.height);
	}

	func valueChanged(slider: UISlider!) {
		//As the slider goes from the minimum to the maximum value,
		//red goes from 0 to 1.  Conversely, blue goes from 1 to 0.

		let red: CGFloat = CGFloat(slider.value - slider.minimumValue)
			/ CGFloat(slider.maximumValue - slider.minimumValue);

		label.backgroundColor = UIColor(red: red, green: 0.0, blue: 1.0 - red, alpha: 1.0);

		//Each number is at least 5 characters wide, with one digit to right of decimal point.
		label.text = String(format: "%5.1f° F = %5.1f° C",
			slider.value, (slider.value - 32) * 100 / (212 - 32));
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect)
	{
		// Drawing code
	}
	*/

}
